@@ -8,8 +8,9 @@ use Pod::Spell;
 use Test::Builder;
 use File::Spec;
 use IPC::Open3;
+use Symbol 'gensym';
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 our @EXPORT = qw(
     pod_file_spelling_ok
@@ -57,7 +58,13 @@ sub _get_spellcheck_results {
     for my $spellchecker (spellchecker_candidates()) {
         my @words;
         my $ok = eval {
-            my $pid = open3((my ($child_in, $spellcheck_results, $child_err)), $spellchecker);
+            # IPC::Open3 says "If CHLD_ERR is false [...] then STDOUT and
+            # STDERR of the child are on the same filehandle (this means that
+            # an autovivified lexical cannot be used for the STDERR
+            # filehandle [...])" - what a crummy API!
+            my $child_error = gensym;
+
+            my $pid = open3(my ($child_in, $spellcheck_results), $child_error, $spellchecker);
 
             print $child_in $document;
 
@@ -66,6 +73,9 @@ sub _get_spellcheck_results {
 
             @words = <$spellcheck_results>;
 
+            my $errors = do { local $/; <$child_error> };
+            die "spellchecker had errors: $errors" if length $errors;
+
             # wait for spellchecker to clean up
             waitpid $pid, 0;
 
@@ -304,12 +314,8 @@ first line looks like a perl shebang line.
 If there is no working spellchecker (determined by
 L</has_working_spellchecker>), this test will issue a "skip all" directive.
 
-If you're testing a distribution, just create a F<t/pod-spell.t>:
-
-    use Test::More;
-    plan skip_all => "Spelling tests only for authors" unless -d "inc/.author";
-    use Test::Spelling;
-    all_pod_files_spelling_ok();
+If you're testing a distribution, just create a F<t/pod-spell.t> with the code
+in the L</SYNOPSIS>.
 
 Returns true if every POD file has correct spelling, or false if any of them fail.
 This function will show any spelling errors as diagnostics.
